package com.zcloud.controller.bus;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;
import org.apache.shiro.authz.annotation.RequiresPermissions;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import com.zcloud.entity.PageData;
import com.zcloud.service.bus.ResourceCorpService;

/** 
 * 说明：资源库企业管理
 * 作者：luoxiaobao
 * 时间：2021-03-22
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/resourcecorp")
public class ResourceCorpController extends BaseController {
	
	@Autowired
	private ResourceCorpService resourcecorpService;
	
	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	@RequiresPermissions("resourcecorp:add")
	@ResponseBody
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			if(ArrayDATA_IDS != null && ArrayDATA_IDS.length > 0) {
				for(String corpId:ArrayDATA_IDS) {
					pd.put("RESOURCECORP_ID", this.get32UUID());	//主键
					pd.put("ISDELETE", "0");	//是否删除
					pd.put("STATUS", "1");	//资源库使用状态   1 启用 2禁用
					pd.put("CORPINFO_ID", corpId);
					pd.put("OPERATOR", Jurisdiction.getUsername());	//操作人
					pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//操作时间
					pd.put("CREATOR", Jurisdiction.getUsername());	//创建人
					pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//创建时间
					resourcecorpService.save(pd);
				}
				errInfo = "success";
			} else {
				errInfo = "error";
			}
		} else {
			errInfo = "error";
		}

		map.put("result", errInfo);
		return map;
	}
	
	/**删除
	 * @param out
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	@RequiresPermissions("resourcecorp:del")
	@ResponseBody
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//操作人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//操作时间
		resourcecorpService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}
	
	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	@RequiresPermissions("resourcecorp:edit")
	@ResponseBody
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		resourcecorpService.edit(pd);
		map.put("result", errInfo);
		return map;
	}
	
	/**修改状态
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/editStatus")
	@RequiresPermissions("resourcecorp:edit")
	@ResponseBody
	public Object editStatus() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//操作人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//操作时间
		resourcecorpService.editStatus(pd);
		map.put("result", errInfo);
		return map;
	}
	
	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	@RequiresPermissions("resourcecorp:list")
	@ResponseBody
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		page.setPd(pd);
		List<PageData>	varList = resourcecorpService.list(page);	//列出ResourceCorp列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}
	
	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	@RequiresPermissions("resourcecorp:edit")
	@ResponseBody
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = resourcecorpService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}	
	
	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	@RequiresPermissions("resourcecorp:del")
	@ResponseBody
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();		
		pd = this.getPageData();

		pd.put("OPERATOR", Jurisdiction.getUsername());	//操作人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//操作时间
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			pd.put("ArrayDATA_IDS", ArrayDATA_IDS);
			resourcecorpService.deleteAll(pd);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}
	
	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	@RequiresPermissions("toExcel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("企业ID");	//1
		titles.add("资源库使用状态   1 启用 2禁用");	//2
		titles.add("是否删除 0 未删除  1已删除");	//3
		titles.add("添加人");	//4
		titles.add("创建时间");	//5
		titles.add("修改人");	//6
		titles.add("修改时间");	//7
		dataMap.put("titles", titles);
		List<PageData> varOList = resourcecorpService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("CORPINFO_ID"));	    //1
			vpd.put("var2", varOList.get(i).getString("STATUS"));	    //2
			vpd.put("var3", varOList.get(i).getString("ISDELETE"));	    //3
			vpd.put("var4", varOList.get(i).getString("CREATOR"));	    //4
			vpd.put("var5", varOList.get(i).getString("CREATTIME"));	    //5
			vpd.put("var6", varOList.get(i).getString("OPERATOR"));	    //6
			vpd.put("var7", varOList.get(i).getString("OPERATTIME"));	    //7
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}
	
}
