package com.zcloud.controller.system;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import com.zcloud.util.*;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.entity.system.Dictionaries;
import com.zcloud.service.system.DictionariesService;
import com.zcloud.service.system.UsersService;

import net.sf.json.JSONArray;

/**
 * 说明：数据字典处理类
 * 作者：luoxiaobao
 * 官网：www.qdkjchina.com
 */
@Controller
@RequestMapping("/dictionaries")
public class DictionariesController extends BaseController {

    @Autowired
    private DictionariesService dictionariesService;
    @Autowired
    private UsersService usersService;


    /**
     * 显示列表ztree
     *
     * @return
     */
    @RequestMapping(value = "/listAllDict")
    @RequiresPermissions("dictionaries:list")
    @ResponseBody
    public Object listAllDict() throws Exception {
        Map<String, String> map = new HashMap<String, String>();
        String errInfo = "success";
        JSONArray arr = JSONArray.fromObject(dictionariesService.listAllDict("0"));
        String json = arr.toString();
        json = json.replaceAll("DICTIONARIES_ID", "id").replaceAll("PARENT_ID", "pId").replaceAll("NAME", "name").replaceAll("subDict", "nodes").replaceAll("hasDict", "checked").replaceAll("treeurl", "url");
        map.put("zTreeNodes", json);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 列表
     *
     * @param page
     * @throws Exception
     */
    @RequestMapping(value = "/list")
    @RequiresPermissions("dictionaries:list")
    @ResponseBody
    public Object list(Page page) throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        String KEYWORDS = pd.getString("KEYWORDS");                        //关键词检索条件
        if (Tools.notEmpty(KEYWORDS)) pd.put("KEYWORDS", KEYWORDS.trim());
        String DICTIONARIES_ID = null == pd.get("DICTIONARIES_ID") ? "" : pd.get("DICTIONARIES_ID").toString();
        pd.put("DICTIONARIES_ID", DICTIONARIES_ID);                        //上级ID
        page.setPd(pd);
        List<PageData> varList = dictionariesService.list(page);        //列出Dictionaries列表
        if ("".equals(DICTIONARIES_ID) || "0".equals(DICTIONARIES_ID)) {
            map.put("PARENT_ID", "0");                                    //上级ID
        } else {
            PageData parent = dictionariesService.findById(pd);
            map.put("PARENT_ID", parent.getString("PARENT_ID")); // 上级ID
            map.put("PARENT_NAME", parent.getString("NAME")); // 上级ID
        }
        map.put("varList", varList);
        map.put("page", page);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 去新增页面
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/goAdd")
    @ResponseBody
    public Object goAdd() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        String DICTIONARIES_ID = null == pd.get("DICTIONARIES_ID") ? "" : pd.get("DICTIONARIES_ID").toString();
        pd.put("DICTIONARIES_ID", DICTIONARIES_ID);                        //上级ID
        map.put("pds", dictionariesService.findById(pd));                //传入上级所有信息
        map.put("result", errInfo);
        return map;
    }

    /**
     * 新增
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/add")
    @ResponseBody
    public Object add() throws Exception {
        Map<String, String> map = new HashMap<String, String>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("DICTIONARIES_ID", this.get32UUID());    //主键
        dictionariesService.save(pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 判断编码是否存在
     *
     * @return
     */
    @RequestMapping(value = "/hasBianma")
    @ResponseBody
    public Object hasBianma() {
        Map<String, String> map = new HashMap<String, String>();
        String errInfo = "success";
        PageData pd = new PageData();
        try {
            pd = this.getPageData();
            if (dictionariesService.findByBianma(pd) != null) {
                errInfo = "error";
            }
        } catch (Exception e) {
            errInfo = "error";
        }
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 去修改页面
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/goEdit")
    @ResponseBody
    public Object goEdit() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd = dictionariesService.findById(pd);                            //根据ID读取
        map.put("pd", pd);                                                //放入视图容器
        pd.put("DICTIONARIES_ID", pd.get("PARENT_ID").toString());        //用作上级信息
        map.put("pds", dictionariesService.findById(pd));                //传入上级所有信息
        map.put("result", errInfo);                                        //返回结果
        return map;
    }

    /**
     * 修改
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/edit")
    @ResponseBody
    public Object edit() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        dictionariesService.edit(pd);
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 删除
     *
     * @param DICTIONARIES_ID
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/delete")
    @ResponseBody
    public Object delete(@RequestParam String DICTIONARIES_ID) throws Exception {
        Map<String, String> map = new HashMap<String, String>();
        PageData pd = new PageData();
        pd.put("DICTIONARIES_ID", DICTIONARIES_ID);
        String errInfo = "success";
        if (dictionariesService.listSubDictByParentId(DICTIONARIES_ID).size() > 0) {//判断是否有子级，是：不允许删除
            errInfo = "error";
        } else {
            pd = dictionariesService.findById(pd);                    //根据ID读取
            if ("yes".equals(pd.getString("YNDEL"))) return null;        //当禁止删除字段值为yes, 则禁止删除，只能从手动从数据库删除
            if (null != pd.get("TBSNAME") && !"".equals(pd.getString("TBSNAME"))) {
                String TBFIELD = pd.getString("TBFIELD");
                if (Tools.isEmpty(TBFIELD)) TBFIELD = "BIANMA";        //如果关联字段没有设置，就默认字段为 BIANMA
                pd.put("TBFIELD", TBFIELD);
                String[] table = pd.getString("TBSNAME").split(",");
                for (int i = 0; i < table.length; i++) {
                    pd.put("thisTable", table[i]);
                    try {
                        if (Integer.parseInt(dictionariesService.findFromTbs(pd).get("zs").toString()) > 0) {//判断是否被占用，是：不允许删除(去排查表检查字典表中的编码字段)
                            errInfo = "error";
                            break;
                        }
                    } catch (Exception e) {
                        errInfo = "error2";
                        break;
                    }
                }
            }
        }
        if ("success".equals(errInfo)) {
            dictionariesService.delete(pd);    //执行删除
        }
        map.put("result", errInfo);
        return map;
    }

    /**
     * 获取连级数据
     *
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/getLevels")
    @ResponseBody
    public Object getLevels() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        String DICTIONARIES_ID = pd.getString("DICTIONARIES_ID");
        DICTIONARIES_ID = Tools.isEmpty(DICTIONARIES_ID) ? "0" : DICTIONARIES_ID;
        List<Dictionaries> varList = dictionariesService.listSubDictByParentId(DICTIONARIES_ID); //用传过来的ID获取此ID下的子列表数据
        List<PageData> pdList = new ArrayList<PageData>();
        for (Dictionaries d : varList) {
            PageData pdf = new PageData();
            pdf.put("DICTIONARIES_ID", d.getDICTIONARIES_ID());
            pdf.put("BIANMA", d.getBIANMA());
            pdf.put("NAME", d.getNAME());
            pdList.add(pdf);
        }
        map.put("list", pdList);
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 获取连级数据
     *
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/getLevelsByBianMa")
    @ResponseBody
    public Object getLevelsByBianMa() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd = dictionariesService.findByBianma(pd);
        String DICTIONARIES_ID = pd.getString("DICTIONARIES_ID");
        DICTIONARIES_ID = Tools.isEmpty(DICTIONARIES_ID) ? "0" : DICTIONARIES_ID;
        List<Dictionaries> varList = dictionariesService.listSubDictByParentId(DICTIONARIES_ID); //用传过来的ID获取此ID下的子列表数据
        List<PageData> pdList = new ArrayList<PageData>();
        for (Dictionaries d : varList) {
            PageData pdf = new PageData();
            pdf.put("DICTIONARIES_ID", d.getDICTIONARIES_ID());
            pdf.put("BIANMA", d.getBIANMA());
            pdf.put("NAME", d.getNAME());
            pdList.add(pdf);
        }
        map.put("list", pdList);
        map.put("result", errInfo);                //返回结果
        return map;
    }


    // cet查询 所有字节点的数据
    @RequestMapping(value = "/listAllDictCetByParentId")
    @ResponseBody
    public ReturnMap listAllDictCetByParentId() {
		PageData pageData = this.getPageData();
		List<PageData> dataList = dictionariesService.listAllDictCetByParentId(pageData);
		return ReturnMap.ok().put("list", dataList);
    }


    /**
     * 显示列表ztree (用于代码生成器引用数据字典)
     *
     * @return
     */
    @RequestMapping(value = "/listAllDictToCreateCode")
    @ResponseBody
    public Object listAllDictToCreateCode() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        JSONArray arr = JSONArray.fromObject(dictionariesService.listAllDictToCreateCode("0"));
        String json = arr.toString();
        json = json.replaceAll("DICTIONARIES_ID", "id").replaceAll("PARENT_ID", "pId").replaceAll("NAME", "name").replaceAll("subDict", "nodes").replaceAll("hasDict", "checked").replaceAll("treeurl", "click");
        map.put("zTreeNodes", json);
        map.put("result", errInfo);                //返回结果
        return map;
    }

    @RequestMapping(value = "/listHylxDictToCreateCode")
    @ResponseBody
    public Object listHylxDictToCreateCode() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
//		String errInfo = "success";
//		JSONArray arr = JSONArray.fromObject(dictionariesService.listAllDictToCreateCode("f2598ba72e864eadabf0ca4b664d26b9"));
//		String json = arr.toString();
//		json = json.replaceAll("DICTIONARIES_ID", "id").replaceAll("PARENT_ID", "pId").replaceAll("NAME", "name").replaceAll("subDict", "nodes").replaceAll("hasDict", "checked").replaceAll("treeurl", "click");
        List<PageData> zdicPdList = new ArrayList<PageData>();
        PageData dic = new PageData();
        if (Tools.isEmpty(pd.get("DICTIONARIES_ID"))) {
            pd.put("DICTIONARIES_ID", "f2598ba72e864eadabf0ca4b664d26b9");
        }
        dic.put("DICTIONARIES_ID", pd.getString("DICTIONARIES_ID"));
        dic = this.dictionariesService.findById(dic);
        PageData node = new PageData();
        node.put("id", dic.get("DICTIONARIES_ID"));
        node.put("parentId", dic.get("PARENT_ID"));
        node.put("name", dic.get("NAME"));
        node.put("icon", "../../../assets/images/user.gif");
        zdicPdList.add(node);
        JSONArray arr = JSONArray.fromObject(dictionariesService.listAllDictToSelect(pd.getString("DICTIONARIES_ID"), zdicPdList));
        map.put("zTreeNodes", (null == arr ? "" : "{\"treeNodes\":" + arr.toString() + "}"));
        map.put("result", errInfo);
        return map;
    }

    @RequestMapping(value = "/listJjlxDictToCreateCode")
    @ResponseBody
    public Object listJjlxDictToCreateCode() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
//		String errInfo = "success";
//		JSONArray arr = JSONArray.fromObject(dictionariesService.listAllDictToCreateCode("f2598ba72e864eadabf0ca4b664d26b9"));
//		String json = arr.toString();
//		json = json.replaceAll("DICTIONARIES_ID", "id").replaceAll("PARENT_ID", "pId").replaceAll("NAME", "name").replaceAll("subDict", "nodes").replaceAll("hasDict", "checked").replaceAll("treeurl", "click");
        List<PageData> zdicPdList = new ArrayList<PageData>();
        PageData dic = new PageData();
        if (Tools.isEmpty(pd.get("DICTIONARIES_ID"))) {
            pd.put("DICTIONARIES_ID", "688d2cf1c6cd4dab999a0106e09aec83");
        }
        dic.put("DICTIONARIES_ID", pd.getString("DICTIONARIES_ID"));
        dic = this.dictionariesService.findById(dic);
        PageData node = new PageData();
        node.put("id", dic.get("DICTIONARIES_ID"));
        node.put("parentId", dic.get("PARENT_ID"));
        node.put("name", dic.get("NAME"));
        node.put("icon", "../../../assets/images/user.gif");
        zdicPdList.add(node);
        JSONArray arr = JSONArray.fromObject(dictionariesService.listAllDictToSelect(pd.getString("DICTIONARIES_ID"), zdicPdList));
        map.put("zTreeNodes", (null == arr ? "" : "{\"treeNodes\":" + arr.toString() + "}"));
        map.put("result", errInfo);
        return map;
    }

    @RequestMapping(value = "/listAllDictToParIdCurrent")
    @ResponseBody
    public Object listAllDictToParIdCurrent() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        List<Dictionaries> _list = dictionariesService.listAllDictToCreateCode(pd.getString("parentId"));
        List<PageData> list = _list.stream().map(Warden::DicToMap).collect(Collectors.toList());
        JSONArray arr = JSONArray.fromObject(list);
        JSONArray arr_old = JSONArray.fromObject(_list);
        String json = arr_old.toString();
        json = json.replaceAll("PARENT_ID", "pId").replaceAll("subDict", "children").replaceAll("hasDict", "checked").replaceAll("treeurl", "click");
        map.put("zTreeNodes", json);

        JSONArray arr_new = JSONArray.fromObject(list);
        String json_new = arr_new.toString();
        json_new = json_new.replaceAll("PARENT_ID", "pId").replaceAll("subDict", "children").replaceAll("hasDict", "checked").replaceAll("treeurl", "click");
        map.put("tree", json_new);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 显示列表ztree
     *
     * @return
     */
    @RequestMapping(value = "/firstListAll")
    @RequiresPermissions("dictionaries:list")
    @ResponseBody
    public Object firstListAll() throws Exception {
        Map<String, String> map = new HashMap<String, String>();
        String errInfo = "success";
        List<Dictionaries> listAll = dictionariesService.listSubDictByParentId("0");
        JSONArray arr = JSONArray.fromObject(listAll);
        String json = arr.toString();
        json = json.replaceAll("DICTIONARIES_ID", "id").replaceAll("PARENT_ID", "pId").replaceAll("NAME", "name").replaceAll("subDict", "nodes").replaceAll("hasDict", "checked").replaceAll("treeurl", "url");
        map.put("zTreeNodes", json);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 去修改页面
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/findByBianma")
    @ResponseBody
    public Object findByBianma() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        map.put("DICTIONARIES_ID", dictionariesService.findByBianma(pd).get("DICTIONARIES_ID"));                //传入上级所有信息
        map.put("result", errInfo);                                        //返回结果
        return map;
    }

    /**
     * 获取连级数据
     *
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/getLevelsAndSCount")
    @ResponseBody
    public Object getLevelsAndSCount() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        String DICTIONARIES_ID = pd.getString("DICTIONARIES_ID");
        DICTIONARIES_ID = Tools.isEmpty(DICTIONARIES_ID) ? "0" : DICTIONARIES_ID;
        List<PageData> varList = dictionariesService.listSubDictByParentIdAndSunCount(DICTIONARIES_ID); //用传过来的ID获取此ID下的子列表数据
        List<PageData> pdList = new ArrayList<PageData>();
        for (PageData d : varList) {
            PageData pdf = new PageData();
            pdf.put("DICTIONARIES_ID", d.getString("DICTIONARIES_ID"));
            pdf.put("BIANMA", d.getString("BIANMA"));
            pdf.put("NAME", d.getString("NAME"));
            pdf.put("disabled", "true");
            pdf.put("zcount", d.get("zcount"));
            pdList.add(pdf);
        }
        map.put("list", pdList);
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 显示列表ztree (用于代码生成器引用数据字典)
     *
     * @return
     */
    @RequestMapping(value = "/listAllDictToParId")
    @ResponseBody
    public Object listAllDictToParId() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        JSONArray arr = JSONArray.fromObject(dictionariesService.listAllDictToCreateCode(pd.getString("parentId")));

        String json = arr.toString().replaceAll("", "");
        json = json.replaceAll("DICTIONARIES_ID", "id").replaceAll("PARENT_ID", "pId").replaceAll("NAME", "name").replaceAll("subDict", "nodes").replaceAll("hasDict", "checked").replaceAll("treeurl", "click");
        String jsonb = json.replaceAll(",\"nodes\":\\[\\]", "");
        map.put("zTreeNodes", jsonb);
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 获取连级数据
     *
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/getAreaDict")
    @ResponseBody
    public Object getAreaDict() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        Map<String, Object> agentArea = new HashMap<String, Object>();
        int agentLevel = 0;
        int level = Integer.valueOf(pd.getString("LEVEL"));
        //String agentArea = "";
        if (!"1".equals(Jurisdiction.getUSER_ID())) {
            PageData user = new PageData();
            user.put("USER_ID", Jurisdiction.getUSER_ID());
            PageData agent = usersService.findById(user);
            if (agent != null && agent.get("AGENTLEVEL") != null && Tools.notEmpty(agent.get("AGENTLEVEL").toString())) {
                agentLevel = Integer.valueOf(agent.get("AGENTLEVEL").toString());
            }
            agentArea.put(agent.getString("AGENTPROVINCE"), "");
            agentArea.put(agent.getString("AGENTCITY"), "");
            agentArea.put(agent.getString("AGENTCOUNTY"), "");
            agentArea.put(agent.getString("AGENTVILLAGE"), "");
            agentArea.put(agent.getString("AGENTSTREET"), "");
        }
        String DICTIONARIES_ID = pd.getString("DICTIONARIES_ID");
        DICTIONARIES_ID = Tools.isEmpty(DICTIONARIES_ID) ? "0" : DICTIONARIES_ID;
        List<PageData> varList = dictionariesService.listSubDictByParentIdAndSunCount(DICTIONARIES_ID); //用传过来的ID获取此ID下的子列表数据
        List<PageData> pdList = new ArrayList<PageData>();
        for (PageData d : varList) {
            PageData pdf = new PageData();
            pdf.put("DICTIONARIES_ID", d.getString("DICTIONARIES_ID"));
            pdf.put("BIANMA", d.getString("BIANMA"));
            pdf.put("NAME", d.getString("NAME"));
            pdf.put("LEVEL", level + 1);

            if (!"1".equals(Jurisdiction.getUSER_ID())) {
                if (level + 1 < agentLevel) {
                    pdf.put("DISABLED", "true");
                    if (!agentArea.containsKey(pdf.getString("BIANMA"))) {
                        pdf.put("zcount", 0);
                    } else {
                        pdf.put("zcount", d.get("zcount"));
                    }
                } else if (level + 1 == agentLevel) {

                    if (!agentArea.containsKey(pdf.getString("BIANMA"))) {
                        pdf.put("DISABLED", "true");
                        pdf.put("zcount", 0);
                    } else {
                        pdf.put("zcount", d.get("zcount"));
                    }
                } else {
                    pdf.put("zcount", d.get("zcount"));
                }
            } else {
                pdf.put("zcount", d.get("zcount"));
            }

            pdList.add(pdf);
        }
        map.put("list", pdList);
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 获取连级数据
     *
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/getAgentAreaDict")
    @ResponseBody
    public Object getAgentAreaDict() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        Map<String, Object> agentArea = new HashMap<String, Object>();
        int agentLevel = 0;
        int level = Integer.valueOf(pd.getString("LEVEL"));
        //String agentArea = "";
        String DICTIONARIES_ID = pd.getString("DICTIONARIES_ID");
        DICTIONARIES_ID = Tools.isEmpty(DICTIONARIES_ID) ? "0" : DICTIONARIES_ID;
        List<PageData> varList = dictionariesService.listSubDictByParentIdAndSunCount(DICTIONARIES_ID); //用传过来的ID获取此ID下的子列表数据
        List<PageData> pdList = new ArrayList<PageData>();
        for (PageData d : varList) {
            PageData pdf = new PageData();
            pdf.put("DICTIONARIES_ID", d.getString("DICTIONARIES_ID"));
            pdf.put("BIANMA", d.getString("BIANMA"));
            pdf.put("NAME", d.getString("NAME"));
            pdf.put("LEVEL", level + 1);

            if (!"1".equals(Jurisdiction.getUSER_ID())) {
                if (level == 0) {
                    if (agentArea.get("AGENCY_PROVINCE") != null && agentArea.get("AGENCY_PROVINCE").toString().indexOf(pdf.getString("BIANMA")) == -1) {
                        pdf.put("DISABLED", "true");
                        pdf.put("zcount", 0);
                    } else {
                        pdf.put("zcount", d.get("zcount"));
                    }
                } else if (level == 1) {
                    if (agentArea.get("AGENCY_CITY") != null && !agentArea.get("AGENCY_CITY").equals("") && agentArea.get("AGENCY_CITY").toString().indexOf(pdf.getString("BIANMA")) == -1) {
                        pdf.put("DISABLED", "true");
                        pdf.put("zcount", 0);
                    } else {
                        pdf.put("zcount", d.get("zcount"));
                    }
                } else if (level == 2) {
                    if (agentArea.get("AGENCY_COUNTY") != null && !agentArea.get("AGENCY_COUNTY").equals("") && agentArea.get("AGENCY_COUNTY").toString().indexOf(pdf.getString("BIANMA")) == -1) {
                        pdf.put("DISABLED", "true");
                        pdf.put("zcount", 0);
                    } else {
                        pdf.put("zcount", d.get("zcount"));
                    }
                } else {
                    pdf.put("zcount", d.get("zcount"));
                }
            } else {
                pdf.put("zcount", d.get("zcount"));
            }

            pdList.add(pdf);
        }
        map.put("list", pdList);
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 获取连级数据
     *
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/getDictTreeMoreLevel")
    @ResponseBody
    public Object getDictTreeMoreLevel() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        String DICTIONARIES_ID = pd.getString("DICTIONARIES_ID");
        List<PageData> varList = dictionariesService.getDictTreeMoreLevel(DICTIONARIES_ID); //用传过来的ID获取此ID下的子列表数据
        map.put("list", varList);
        map.put("result", errInfo);                //返回结果
        return map;
    }
}
